# Installation
ThermalNetwork is intended to be used via [URBANopt](https://docs.urbanopt.net). From within the URBANopt CLI, ThermalNetwork is one of the Python packages that is installed via the `uo install_python` command. Once that has been done, `uo ghe_size` becomes available as seen in the [usage](usage.md) page.

# Developer installation
ThermalNetwork can be installed by cloning the repository (GitHub link at top) and following the [developer installation instructions](https://github.com/NREL/ThermalNetwork?tab=readme-ov-file#developer-installation).
